[![pipeline](https://github.com/lhelleckes/murefi/workflows/pipeline/badge.svg)](https://github.com/lhelleckes/murefi/actions)

[![coverage](https://codecov.io/gh/jubiotech/murefi/branch/master/graph/badge.svg)](https://codecov.io/gh/jubiotech/murefi)
[![documentation](https://readthedocs.org/projects/murefi/badge/?version=latest)](https://murefi.readthedocs.io/en/latest/?badge=latest)

# `murefi`
This package provides useful data structures and mapping objects for __mu__&#x200b;lti-__re__&#x200b;plicate __fi__&#x200b;tting, mainly of ordinary differential euqation (ODE) models. 
To see implementation examples & excercises, you can go to [notebooks/](notebooks).

# Documentation
Read the package documentation [here](https://murefi.readthedocs.io/en/latest/?badge=latest).

# Usage and Citing
`murefi` is licensed under the [GNU Affero General Public License v3.0](https://github.com/jubiotech/murefi/blob/master/LICENSE).

